@@ -1,4 +1,4 @@
-import sys, py, pytest
+import py, pytest
 
 class TestGeneralUsage:
     def test_config_error(self, testdir):
@@ -14,7 +14,7 @@ class TestGeneralUsage:
         ])
 
     def test_root_conftest_syntax_error(self, testdir):
-        p = testdir.makepyfile(conftest="raise SyntaxError\n")
+        testdir.makepyfile(conftest="raise SyntaxError\n")
         result = testdir.runpytest()
         result.stderr.fnmatch_lines(["*raise SyntaxError*"])
         assert result.ret != 0
@@ -67,7 +67,7 @@ class TestGeneralUsage:
         result = testdir.runpytest("-s", "asd")
         assert result.ret == 4 # EXIT_USAGEERROR
         result.stderr.fnmatch_lines(["ERROR: file not found*asd"])
-        s = result.stdout.fnmatch_lines([
+        result.stdout.fnmatch_lines([
             "*---configure",
             "*---unconfigure",
         ])
@@ -307,6 +307,24 @@ class TestGeneralUsage:
                 '*ERROR*',
             ])
             assert result.ret == 4  # usage error only if item not found
+    
+    def test_namespace_import_doesnt_confuse_import_hook(self, testdir):
+        # Ref #383. Python 3.3's namespace package messed with our import hooks
+        # Importing a module that didn't exist, even if the ImportError was
+        # gracefully handled, would make our test crash.
+        testdir.mkdir('not_a_package')
+        p = testdir.makepyfile("""
+            try:
+                from not_a_package import doesnt_exist
+            except ImportError:
+                # We handle the import error gracefully here
+                pass
+            
+            def test_whatever():
+                pass
+        """)
+        res = testdir.runpytest(p.basename)
+        assert res.ret == 0
 
 
 class TestInvocationVariants:
@@ -539,7 +557,6 @@ class TestDurations:
         assert result.ret == 0
         for x in "123":
             for y in 'call',: #'setup', 'call', 'teardown':
-                l = []
                 for line in result.stdout.lines:
                     if ("test_%s" % x) in line and y in line:
                         break
