@@ -13,7 +13,7 @@ class TestMark:
 
     def test_pytest_mark_notcallable(self):
         mark = Mark()
-        pytest.raises((AttributeError, TypeError), "mark()")
+        pytest.raises((AttributeError, TypeError), mark)
 
     def test_pytest_mark_bare(self):
         mark = Mark()
@@ -35,7 +35,7 @@ class TestMark:
         mark = Mark()
         def f():
             pass
-        marker = mark.world
+        mark.world
         mark.world(x=3)(f)
         assert f.world.kwargs['x'] == 3
         mark.world(y=4)(f)
@@ -100,6 +100,16 @@ def test_markers_option(testdir):
         "*a1some*another marker",
     ])
 
+def test_mark_on_pseudo_function(testdir):
+    testdir.makepyfile("""
+        import pytest
+
+        @pytest.mark.r(lambda x: 0/0)
+        def test_hello():
+            pass
+    """)
+    reprec = testdir.inline_run()
+    reprec.assertoutcome(passed=1)
 
 def test_strict_prohibits_unregistered_markers(testdir):
     testdir.makepyfile("""
@@ -114,7 +124,7 @@ def test_strict_prohibits_unregistered_markers(testdir):
         "*unregisteredmark*not*registered*",
     ])
 
-@pytest.mark.multi(spec=[
+@pytest.mark.parametrize("spec", [
         ("xyz", ("test_one",)),
         ("xyz and xyz2", ()),
         ("xyz2", ("test_two",)),
@@ -137,7 +147,7 @@ def test_mark_option(spec, testdir):
     assert len(passed) == len(passed_result)
     assert list(passed) == list(passed_result)
 
-@pytest.mark.multi(spec=[
+@pytest.mark.parametrize("spec", [
         ("interface", ("test_interface",)),
         ("not interface", ("test_nointer",)),
 ])
@@ -162,9 +172,11 @@ def test_mark_option_custom(spec, testdir):
     assert len(passed) == len(passed_result)
     assert list(passed) == list(passed_result)
 
-@pytest.mark.multi(spec=[
+@pytest.mark.parametrize("spec", [
         ("interface", ("test_interface",)),
-        ("not interface", ("test_nointer",)),
+        ("not interface", ("test_nointer", "test_pass")),
+        ("pass", ("test_pass",)),
+        ("not pass", ("test_interface", "test_nointer")),
 ])
 def test_keyword_option_custom(spec, testdir):
     testdir.makepyfile("""
@@ -172,6 +184,8 @@ def test_keyword_option_custom(spec, testdir):
             pass
         def test_nointer():
             pass
+        def test_pass():
+            pass
     """)
     opt, passed_result = spec
     rec = testdir.inline_run("-k", opt)
@@ -181,6 +195,24 @@ def test_keyword_option_custom(spec, testdir):
     assert list(passed) == list(passed_result)
 
 
+@pytest.mark.parametrize("spec", [
+        ("None", ("test_func[None]",)),
+        ("1.3", ("test_func[1.3]",))
+])
+def test_keyword_option_parametrize(spec, testdir):
+    testdir.makepyfile("""
+        import pytest
+        @pytest.mark.parametrize("arg", [None, 1.3])
+        def test_func(arg):
+            pass
+    """)
+    opt, passed_result = spec
+    rec = testdir.inline_run("-k", opt)
+    passed, skipped, fail = rec.listoutcomes()
+    passed = [x.nodeid.split("::")[-1] for x in passed]
+    assert len(passed) == len(passed_result)
+    assert list(passed) == list(passed_result)
+
 class TestFunctional:
 
     def test_mark_per_function(self, testdir):
@@ -364,7 +396,7 @@ class TestFunctional:
         assert len(deselected_tests) == 2
 
     def test_keywords_at_node_level(self, testdir):
-        p = testdir.makepyfile("""
+        testdir.makepyfile("""
             import pytest
             @pytest.fixture(scope="session", autouse=True)
             def some(request):
@@ -510,3 +542,4 @@ class TestKeywordSelection:
 
         assert_test_is_not_selected("__")
         assert_test_is_not_selected("()")
+
