@@ -1,6 +1,7 @@
+from __future__ import with_statement
+
 import pytest, py, sys, os
 from _pytest import runner, main
-from py._code.code import ReprExceptionInfo
 
 class TestSetupState:
     def test_setup(self, testdir):
@@ -39,10 +40,39 @@ class TestSetupState:
             def setup_module(mod):
                 raise ValueError(42)
             def test_func(): pass
-        """)
+        """) # noqa
         ss = runner.SetupState()
-        pytest.raises(ValueError, "ss.prepare(item)")
-        pytest.raises(ValueError, "ss.prepare(item)")
+        pytest.raises(ValueError, lambda: ss.prepare(item))
+        pytest.raises(ValueError, lambda: ss.prepare(item))
+
+    def test_teardown_multiple_one_fails(self, testdir):
+        r = []
+        def fin1(): r.append('fin1')
+        def fin2(): raise Exception('oops')
+        def fin3(): r.append('fin3')
+        item = testdir.getitem("def test_func(): pass")
+        ss = runner.SetupState()
+        ss.addfinalizer(fin1, item)
+        ss.addfinalizer(fin2, item)
+        ss.addfinalizer(fin3, item)
+        with pytest.raises(Exception) as err:
+            ss._callfinalizers(item)
+        assert err.value.args == ('oops',)
+        assert r == ['fin3', 'fin1']
+
+    def test_teardown_multiple_fail(self, testdir):
+        # Ensure the first exception is the one which is re-raised.
+        # Ideally both would be reported however.
+        def fin1(): raise Exception('oops1')
+        def fin2(): raise Exception('oops2')
+        item = testdir.getitem("def test_func(): pass")
+        ss = runner.SetupState()
+        ss.addfinalizer(fin1, item)
+        ss.addfinalizer(fin2, item)
+        with pytest.raises(Exception) as err:
+            ss._callfinalizers(item)
+        assert err.value.args == ('oops2',)
+
 
 class BaseFunctionalTests:
     def test_passfunction(self, testdir):
@@ -428,7 +458,7 @@ def test_importorskip():
     def f():
         importorskip("asdlkj")
     try:
-        sys = importorskip("sys")
+        sys = importorskip("sys")  # noqa
         assert sys == py.std.sys
         #path = py.test.importorskip("os.path")
         #assert path == py.std.os.path
@@ -439,12 +469,14 @@ def test_importorskip():
         assert path.purebasename == "test_runner"
         pytest.raises(SyntaxError, "py.test.importorskip('x y z')")
         pytest.raises(SyntaxError, "py.test.importorskip('x=y')")
-        path = importorskip("py", minversion=".".join(py.__version__))
         mod = py.std.types.ModuleType("hello123")
         mod.__version__ = "1.3"
+        sys.modules["hello123"] = mod
         pytest.raises(pytest.skip.Exception, """
-            py.test.importorskip("hello123", minversion="5.0")
+            py.test.importorskip("hello123", minversion="1.3.1")
         """)
+        mod2 = pytest.importorskip("hello123", minversion="1.3")
+        assert mod2 == mod
     except pytest.skip.Exception:
         print(py.code.ExceptionInfo())
         py.test.fail("spurious skip")
@@ -464,7 +496,7 @@ def test_pytest_cmdline_main(testdir):
     """)
     import subprocess
     popen = subprocess.Popen([sys.executable, str(p)], stdout=subprocess.PIPE)
-    s = popen.stdout.read()
+    popen.communicate()
     ret = popen.wait()
     assert ret == 0
 
